==> armadillo-0.1.2.zip: src/jp/sourceforge/armadillo/lzh/LzhInputStream.java <==
package jp.sourceforge.armadillo.lzh;

import java.io.*;

import jp.sourceforge.armadillo.io.*;

/**
 * LZH`A[JCu̓̓Xg[B
 */
public final class LzhInputStream extends ArchiveInputStream {

    private LzhHeader header;

    /**
     * LzhInputStream̐B
     * @param is InputStream
     */
    public LzhInputStream(InputStream is) {
        super(is);
        this.header = new LzhHeader();
    }

    /**
     * ̃Gg擾B
     * @return LzhEntry ̃Ggꍇ <code>null</code>
     * @throws IOException o̓G[ꍇ
     */
    public LzhEntry getNextEntry() throws IOException {
        ensureOpen();
        if (remaining > 0) {
            closeEntry();
        }
        LzhEntry entry = header.read(in);
        if (entry == null) {
            return null;
        }
        LzhMethod method = new LzhMethod(entry.getMethod());
        if (method.isCompressing()) {
            frontStream = new LzssInputStream(new LzhHuffmanDecoder(in),
                                              method.getDictionarySize(),
                                              method.getMatchSize(),
                                              method.getThreshold());
        } else {
            frontStream = in;
        }
        remaining = entry.getSize();
        return entry;
    }

    /**
     * ݂̃GgB
     * @throws IOException o̓G[ꍇ
     */
    public void closeEntry() throws IOException {
        ensureOpen();
        while (remaining > 0) {
            long skipped = in.skip(remaining);
            if (skipped < 0) {
                break;
            }
            remaining -= skipped;
        }
        assert remaining == 0 : "rest=" + remaining;
        frontStream = in;
    }

    /* (overridden)
     * @see java.io.InputStream#close()
     */
    public void close() throws IOException {
        header = null;
        super.close();
    }

}

==> armadillo-0.1.3.zip: src/jp/sourceforge/armadillo/lzh/LzhInputStream.java <==
package jp.sourceforge.armadillo.lzh;

import java.io.*;

import jp.sourceforge.armadillo.io.*;

/**
 * LZH`A[JCu̓̓Xg[B
 */
public final class LzhInputStream extends ArchiveInputStream {

    private LzhHeader header;

    /**
     * LzhInputStream̐B
     * @param is InputStream
     */
    public LzhInputStream(InputStream is) {
        super(is);
        this.header = new LzhHeader();
    }

    /**
     * ̃Gg擾B
     * @return LzhEntry ̃Ggꍇ <code>null</code>
     * @throws IOException o̓G[ꍇ
     */
    public LzhEntry getNextEntry() throws IOException {
        ensureOpen();
        if (remaining > 0) {
            closeEntry();
        }
        LzhEntry entry = header.read(in);
        if (entry == null) {
            return null;
        }
        LzhMethod method = new LzhMethod(entry.getMethod());
        if (method.isCompressing()) {
            frontStream = new LzssInputStream(new LzhHuffmanDecoder(in),
                                              method.getDictionarySize(),
                                              method.getMatchSize(),
                                              method.getThreshold());
            remaining = entry.getCompressedSize();
        } else {
            frontStream = in;
            remaining = entry.getSize();
        }
        return entry;
    }

    /**
     * ݂̃GgB
     * @throws IOException o̓G[ꍇ
     */
    public void closeEntry() throws IOException {
        ensureOpen();
        while (remaining > 0) {
            long skipped;
            if (frontStream == in) {
                skipped = skip(remaining);
            } else {
                skipped = in.skip(remaining);
                remaining -= skipped;
            }
            //            skipped = skip(remaining);
            if (skipped < 0) {
                break;
            }
        }
        assert remaining == 0 : "rest=" + remaining;
        frontStream = in;
    }

    /* (overridden)
     * @see java.io.InputStream#close()
     */
    public void close() throws IOException {
        header = null;
        super.close();
    }

}
